@@ -6,7 +6,9 @@ jQuery(document).ready(function() {
         if ( selected_action.match('(replace|merge)') ) {
             var user_id = $this.attr('data-autocreated-userid');
             var $merge_field = jQuery('input[name="merge-user-' +  user_id + '"]');
-            $merge_field.val( $merge_field.attr('placeholder') );
+            if ( !$merge_field.val() ) {
+                $merge_field.val( $merge_field.attr('placeholder') );
+            }
         }
     });
 
